# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetNotebookResult',
    'AwaitableGetNotebookResult',
    'get_notebook',
    'get_notebook_output',
]

@pulumi.output_type
class GetNotebookResult:
    """
    A collection of values returned by getNotebook.
    """
    def __init__(__self__, content=None, format=None, id=None, language=None, object_id=None, object_type=None, path=None):
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if format and not isinstance(format, str):
            raise TypeError("Expected argument 'format' to be a str")
        pulumi.set(__self__, "format", format)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if language and not isinstance(language, str):
            raise TypeError("Expected argument 'language' to be a str")
        pulumi.set(__self__, "language", language)
        if object_id and not isinstance(object_id, int):
            raise TypeError("Expected argument 'object_id' to be a int")
        pulumi.set(__self__, "object_id", object_id)
        if object_type and not isinstance(object_type, str):
            raise TypeError("Expected argument 'object_type' to be a str")
        pulumi.set(__self__, "object_type", object_type)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        notebook content in selected format
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter
    def format(self) -> str:
        return pulumi.get(self, "format")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def language(self) -> str:
        """
        notebook language
        """
        return pulumi.get(self, "language")

    @property
    @pulumi.getter(name="objectId")
    def object_id(self) -> int:
        """
        notebook object ID
        """
        return pulumi.get(self, "object_id")

    @property
    @pulumi.getter(name="objectType")
    def object_type(self) -> str:
        """
        notebook object type
        """
        return pulumi.get(self, "object_type")

    @property
    @pulumi.getter
    def path(self) -> str:
        return pulumi.get(self, "path")


class AwaitableGetNotebookResult(GetNotebookResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNotebookResult(
            content=self.content,
            format=self.format,
            id=self.id,
            language=self.language,
            object_id=self.object_id,
            object_type=self.object_type,
            path=self.path)


def get_notebook(format: Optional[str] = None,
                 language: Optional[str] = None,
                 object_id: Optional[int] = None,
                 object_type: Optional[str] = None,
                 path: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNotebookResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    features = databricks.get_notebook(format="SOURCE",
        path="/Production/Features")
    ```


    :param str format: Notebook format to export. Either `SOURCE`, `HTML`, `JUPYTER`, or `DBC`.
    :param str language: notebook language
    :param int object_id: notebook object ID
    :param str object_type: notebook object type
    :param str path: Notebook path on the workspace
    """
    __args__ = dict()
    __args__['format'] = format
    __args__['language'] = language
    __args__['objectId'] = object_id
    __args__['objectType'] = object_type
    __args__['path'] = path
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('databricks:index/getNotebook:getNotebook', __args__, opts=opts, typ=GetNotebookResult).value

    return AwaitableGetNotebookResult(
        content=__ret__.content,
        format=__ret__.format,
        id=__ret__.id,
        language=__ret__.language,
        object_id=__ret__.object_id,
        object_type=__ret__.object_type,
        path=__ret__.path)


@_utilities.lift_output_func(get_notebook)
def get_notebook_output(format: Optional[pulumi.Input[str]] = None,
                        language: Optional[pulumi.Input[Optional[str]]] = None,
                        object_id: Optional[pulumi.Input[Optional[int]]] = None,
                        object_type: Optional[pulumi.Input[Optional[str]]] = None,
                        path: Optional[pulumi.Input[str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNotebookResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    features = databricks.get_notebook(format="SOURCE",
        path="/Production/Features")
    ```


    :param str format: Notebook format to export. Either `SOURCE`, `HTML`, `JUPYTER`, or `DBC`.
    :param str language: notebook language
    :param int object_id: notebook object ID
    :param str object_type: notebook object type
    :param str path: Notebook path on the workspace
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['AzureBlobMountArgs', 'AzureBlobMount']

@pulumi.input_type
class AzureBlobMountArgs:
    def __init__(__self__, *,
                 auth_type: pulumi.Input[str],
                 container_name: pulumi.Input[str],
                 mount_name: pulumi.Input[str],
                 storage_account_name: pulumi.Input[str],
                 token_secret_key: pulumi.Input[str],
                 token_secret_scope: pulumi.Input[str],
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 directory: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AzureBlobMount resource.
        """
        pulumi.set(__self__, "auth_type", auth_type)
        pulumi.set(__self__, "container_name", container_name)
        pulumi.set(__self__, "mount_name", mount_name)
        pulumi.set(__self__, "storage_account_name", storage_account_name)
        pulumi.set(__self__, "token_secret_key", token_secret_key)
        pulumi.set(__self__, "token_secret_scope", token_secret_scope)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if directory is not None:
            pulumi.set(__self__, "directory", directory)

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "auth_type")

    @auth_type.setter
    def auth_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "auth_type", value)

    @property
    @pulumi.getter(name="containerName")
    def container_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "container_name")

    @container_name.setter
    def container_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "container_name", value)

    @property
    @pulumi.getter(name="mountName")
    def mount_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "mount_name")

    @mount_name.setter
    def mount_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "mount_name", value)

    @property
    @pulumi.getter(name="storageAccountName")
    def storage_account_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "storage_account_name")

    @storage_account_name.setter
    def storage_account_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "storage_account_name", value)

    @property
    @pulumi.getter(name="tokenSecretKey")
    def token_secret_key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "token_secret_key")

    @token_secret_key.setter
    def token_secret_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "token_secret_key", value)

    @property
    @pulumi.getter(name="tokenSecretScope")
    def token_secret_scope(self) -> pulumi.Input[str]:
        return pulumi.get(self, "token_secret_scope")

    @token_secret_scope.setter
    def token_secret_scope(self, value: pulumi.Input[str]):
        pulumi.set(self, "token_secret_scope", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def directory(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "directory")

    @directory.setter
    def directory(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "directory", value)


@pulumi.input_type
class _AzureBlobMountState:
    def __init__(__self__, *,
                 auth_type: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 container_name: Optional[pulumi.Input[str]] = None,
                 directory: Optional[pulumi.Input[str]] = None,
                 mount_name: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 storage_account_name: Optional[pulumi.Input[str]] = None,
                 token_secret_key: Optional[pulumi.Input[str]] = None,
                 token_secret_scope: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AzureBlobMount resources.
        """
        if auth_type is not None:
            pulumi.set(__self__, "auth_type", auth_type)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if container_name is not None:
            pulumi.set(__self__, "container_name", container_name)
        if directory is not None:
            pulumi.set(__self__, "directory", directory)
        if mount_name is not None:
            pulumi.set(__self__, "mount_name", mount_name)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if storage_account_name is not None:
            pulumi.set(__self__, "storage_account_name", storage_account_name)
        if token_secret_key is not None:
            pulumi.set(__self__, "token_secret_key", token_secret_key)
        if token_secret_scope is not None:
            pulumi.set(__self__, "token_secret_scope", token_secret_scope)

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "auth_type")

    @auth_type.setter
    def auth_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_type", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="containerName")
    def container_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "container_name")

    @container_name.setter
    def container_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_name", value)

    @property
    @pulumi.getter
    def directory(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "directory")

    @directory.setter
    def directory(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "directory", value)

    @property
    @pulumi.getter(name="mountName")
    def mount_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "mount_name")

    @mount_name.setter
    def mount_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mount_name", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter(name="storageAccountName")
    def storage_account_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "storage_account_name")

    @storage_account_name.setter
    def storage_account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_account_name", value)

    @property
    @pulumi.getter(name="tokenSecretKey")
    def token_secret_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "token_secret_key")

    @token_secret_key.setter
    def token_secret_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_secret_key", value)

    @property
    @pulumi.getter(name="tokenSecretScope")
    def token_secret_scope(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "token_secret_scope")

    @token_secret_scope.setter
    def token_secret_scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_secret_scope", value)


class AzureBlobMount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_type: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 container_name: Optional[pulumi.Input[str]] = None,
                 directory: Optional[pulumi.Input[str]] = None,
                 mount_name: Optional[pulumi.Input[str]] = None,
                 storage_account_name: Optional[pulumi.Input[str]] = None,
                 token_secret_key: Optional[pulumi.Input[str]] = None,
                 token_secret_scope: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a AzureBlobMount resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AzureBlobMountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a AzureBlobMount resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AzureBlobMountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AzureBlobMountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_type: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 container_name: Optional[pulumi.Input[str]] = None,
                 directory: Optional[pulumi.Input[str]] = None,
                 mount_name: Optional[pulumi.Input[str]] = None,
                 storage_account_name: Optional[pulumi.Input[str]] = None,
                 token_secret_key: Optional[pulumi.Input[str]] = None,
                 token_secret_scope: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AzureBlobMountArgs.__new__(AzureBlobMountArgs)

            if auth_type is None and not opts.urn:
                raise TypeError("Missing required property 'auth_type'")
            __props__.__dict__["auth_type"] = auth_type
            __props__.__dict__["cluster_id"] = cluster_id
            if container_name is None and not opts.urn:
                raise TypeError("Missing required property 'container_name'")
            __props__.__dict__["container_name"] = container_name
            __props__.__dict__["directory"] = directory
            if mount_name is None and not opts.urn:
                raise TypeError("Missing required property 'mount_name'")
            __props__.__dict__["mount_name"] = mount_name
            if storage_account_name is None and not opts.urn:
                raise TypeError("Missing required property 'storage_account_name'")
            __props__.__dict__["storage_account_name"] = storage_account_name
            if token_secret_key is None and not opts.urn:
                raise TypeError("Missing required property 'token_secret_key'")
            __props__.__dict__["token_secret_key"] = token_secret_key
            if token_secret_scope is None and not opts.urn:
                raise TypeError("Missing required property 'token_secret_scope'")
            __props__.__dict__["token_secret_scope"] = token_secret_scope
            __props__.__dict__["source"] = None
        super(AzureBlobMount, __self__).__init__(
            'databricks:index/azureBlobMount:AzureBlobMount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_type: Optional[pulumi.Input[str]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            container_name: Optional[pulumi.Input[str]] = None,
            directory: Optional[pulumi.Input[str]] = None,
            mount_name: Optional[pulumi.Input[str]] = None,
            source: Optional[pulumi.Input[str]] = None,
            storage_account_name: Optional[pulumi.Input[str]] = None,
            token_secret_key: Optional[pulumi.Input[str]] = None,
            token_secret_scope: Optional[pulumi.Input[str]] = None) -> 'AzureBlobMount':
        """
        Get an existing AzureBlobMount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AzureBlobMountState.__new__(_AzureBlobMountState)

        __props__.__dict__["auth_type"] = auth_type
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["container_name"] = container_name
        __props__.__dict__["directory"] = directory
        __props__.__dict__["mount_name"] = mount_name
        __props__.__dict__["source"] = source
        __props__.__dict__["storage_account_name"] = storage_account_name
        __props__.__dict__["token_secret_key"] = token_secret_key
        __props__.__dict__["token_secret_scope"] = token_secret_scope
        return AzureBlobMount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> pulumi.Output[str]:
        return pulumi.get(self, "auth_type")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="containerName")
    def container_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "container_name")

    @property
    @pulumi.getter
    def directory(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "directory")

    @property
    @pulumi.getter(name="mountName")
    def mount_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "mount_name")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output[str]:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="storageAccountName")
    def storage_account_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "storage_account_name")

    @property
    @pulumi.getter(name="tokenSecretKey")
    def token_secret_key(self) -> pulumi.Output[str]:
        return pulumi.get(self, "token_secret_key")

    @property
    @pulumi.getter(name="tokenSecretScope")
    def token_secret_scope(self) -> pulumi.Output[str]:
        return pulumi.get(self, "token_secret_scope")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetSparkVersionResult',
    'AwaitableGetSparkVersionResult',
    'get_spark_version',
    'get_spark_version_output',
]

@pulumi.output_type
class GetSparkVersionResult:
    """
    A collection of values returned by getSparkVersion.
    """
    def __init__(__self__, beta=None, genomics=None, gpu=None, graviton=None, id=None, latest=None, long_term_support=None, ml=None, photon=None, scala=None, spark_version=None):
        if beta and not isinstance(beta, bool):
            raise TypeError("Expected argument 'beta' to be a bool")
        pulumi.set(__self__, "beta", beta)
        if genomics and not isinstance(genomics, bool):
            raise TypeError("Expected argument 'genomics' to be a bool")
        pulumi.set(__self__, "genomics", genomics)
        if gpu and not isinstance(gpu, bool):
            raise TypeError("Expected argument 'gpu' to be a bool")
        pulumi.set(__self__, "gpu", gpu)
        if graviton and not isinstance(graviton, bool):
            raise TypeError("Expected argument 'graviton' to be a bool")
        pulumi.set(__self__, "graviton", graviton)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if latest and not isinstance(latest, bool):
            raise TypeError("Expected argument 'latest' to be a bool")
        pulumi.set(__self__, "latest", latest)
        if long_term_support and not isinstance(long_term_support, bool):
            raise TypeError("Expected argument 'long_term_support' to be a bool")
        pulumi.set(__self__, "long_term_support", long_term_support)
        if ml and not isinstance(ml, bool):
            raise TypeError("Expected argument 'ml' to be a bool")
        pulumi.set(__self__, "ml", ml)
        if photon and not isinstance(photon, bool):
            raise TypeError("Expected argument 'photon' to be a bool")
        pulumi.set(__self__, "photon", photon)
        if scala and not isinstance(scala, str):
            raise TypeError("Expected argument 'scala' to be a str")
        pulumi.set(__self__, "scala", scala)
        if spark_version and not isinstance(spark_version, str):
            raise TypeError("Expected argument 'spark_version' to be a str")
        pulumi.set(__self__, "spark_version", spark_version)

    @property
    @pulumi.getter
    def beta(self) -> Optional[bool]:
        return pulumi.get(self, "beta")

    @property
    @pulumi.getter
    def genomics(self) -> Optional[bool]:
        return pulumi.get(self, "genomics")

    @property
    @pulumi.getter
    def gpu(self) -> Optional[bool]:
        return pulumi.get(self, "gpu")

    @property
    @pulumi.getter
    def graviton(self) -> Optional[bool]:
        return pulumi.get(self, "graviton")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def latest(self) -> Optional[bool]:
        return pulumi.get(self, "latest")

    @property
    @pulumi.getter(name="longTermSupport")
    def long_term_support(self) -> Optional[bool]:
        return pulumi.get(self, "long_term_support")

    @property
    @pulumi.getter
    def ml(self) -> Optional[bool]:
        return pulumi.get(self, "ml")

    @property
    @pulumi.getter
    def photon(self) -> Optional[bool]:
        return pulumi.get(self, "photon")

    @property
    @pulumi.getter
    def scala(self) -> Optional[str]:
        return pulumi.get(self, "scala")

    @property
    @pulumi.getter(name="sparkVersion")
    def spark_version(self) -> Optional[str]:
        return pulumi.get(self, "spark_version")


class AwaitableGetSparkVersionResult(GetSparkVersionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSparkVersionResult(
            beta=self.beta,
            genomics=self.genomics,
            gpu=self.gpu,
            graviton=self.graviton,
            id=self.id,
            latest=self.latest,
            long_term_support=self.long_term_support,
            ml=self.ml,
            photon=self.photon,
            scala=self.scala,
            spark_version=self.spark_version)


def get_spark_version(beta: Optional[bool] = None,
                      genomics: Optional[bool] = None,
                      gpu: Optional[bool] = None,
                      graviton: Optional[bool] = None,
                      latest: Optional[bool] = None,
                      long_term_support: Optional[bool] = None,
                      ml: Optional[bool] = None,
                      photon: Optional[bool] = None,
                      scala: Optional[str] = None,
                      spark_version: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSparkVersionResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    with_gpu = databricks.get_node_type(local_disk=True,
        min_cores=16,
        gb_per_core=1,
        min_gpus=1)
    gpu_ml = databricks.get_spark_version(gpu=True,
        ml=True)
    research = databricks.Cluster("research",
        cluster_name="Research Cluster",
        spark_version=gpu_ml.id,
        node_type_id=with_gpu.id,
        autotermination_minutes=20,
        autoscale=databricks.ClusterAutoscaleArgs(
            min_workers=1,
            max_workers=50,
        ))
    ```
    ## Related Resources

    The following resources are used in the same context:

    * End to end workspace management guide
    * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
    * ClusterPolicy to create a Cluster policy, which limits the ability to create clusters based on a set of rules.
    * InstancePool to manage [instance pools](https://docs.databricks.com/clusters/instance-pools/index.html) to reduce cluster start and auto-scaling times by maintaining a set of idle, ready-to-use instances.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code in a databricks_cluster.


    :param bool beta: if we should limit the search only to runtimes that are in Beta stage. Default to `false`.
    :param bool genomics: if we should limit the search only to Genomics (HLS) runtimes. Default to `false`.
    :param bool gpu: if we should limit the search only to runtimes that support GPUs. Default to `false`.
    :param bool graviton: if we should limit the search only to runtimes supporting AWS Graviton CPUs. Default to `false`.
    :param bool latest: if we should return only the latest version if there is more than one result.  Default to `true`. If set to `false` and multiple versions are matching, throws an error.
    :param bool long_term_support: if we should limit the search only to LTS (long term support) & ESR (extended support) versions. Default to `false`.
    :param bool ml: if we should limit the search only to ML runtimes. Default to `false`.
    :param bool photon: if we should limit the search only to Photon runtimes. Default to `false`.
    :param str scala: if we should limit the search only to runtimes that are based on specific Scala version. Default to `2.12`.
    :param str spark_version: if we should limit the search only to runtimes that are based on specific Spark version. Default to empty string.  It could be specified as `3`, or `3.0`, or full version, like, `3.0.1`.
    """
    __args__ = dict()
    __args__['beta'] = beta
    __args__['genomics'] = genomics
    __args__['gpu'] = gpu
    __args__['graviton'] = graviton
    __args__['latest'] = latest
    __args__['longTermSupport'] = long_term_support
    __args__['ml'] = ml
    __args__['photon'] = photon
    __args__['scala'] = scala
    __args__['sparkVersion'] = spark_version
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('databricks:index/getSparkVersion:getSparkVersion', __args__, opts=opts, typ=GetSparkVersionResult).value

    return AwaitableGetSparkVersionResult(
        beta=__ret__.beta,
        genomics=__ret__.genomics,
        gpu=__ret__.gpu,
        graviton=__ret__.graviton,
        id=__ret__.id,
        latest=__ret__.latest,
        long_term_support=__ret__.long_term_support,
        ml=__ret__.ml,
        photon=__ret__.photon,
        scala=__ret__.scala,
        spark_version=__ret__.spark_version)


@_utilities.lift_output_func(get_spark_version)
def get_spark_version_output(beta: Optional[pulumi.Input[Optional[bool]]] = None,
                             genomics: Optional[pulumi.Input[Optional[bool]]] = None,
                             gpu: Optional[pulumi.Input[Optional[bool]]] = None,
                             graviton: Optional[pulumi.Input[Optional[bool]]] = None,
                             latest: Optional[pulumi.Input[Optional[bool]]] = None,
                             long_term_support: Optional[pulumi.Input[Optional[bool]]] = None,
                             ml: Optional[pulumi.Input[Optional[bool]]] = None,
                             photon: Optional[pulumi.Input[Optional[bool]]] = None,
                             scala: Optional[pulumi.Input[Optional[str]]] = None,
                             spark_version: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSparkVersionResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    with_gpu = databricks.get_node_type(local_disk=True,
        min_cores=16,
        gb_per_core=1,
        min_gpus=1)
    gpu_ml = databricks.get_spark_version(gpu=True,
        ml=True)
    research = databricks.Cluster("research",
        cluster_name="Research Cluster",
        spark_version=gpu_ml.id,
        node_type_id=with_gpu.id,
        autotermination_minutes=20,
        autoscale=databricks.ClusterAutoscaleArgs(
            min_workers=1,
            max_workers=50,
        ))
    ```
    ## Related Resources

    The following resources are used in the same context:

    * End to end workspace management guide
    * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
    * ClusterPolicy to create a Cluster policy, which limits the ability to create clusters based on a set of rules.
    * InstancePool to manage [instance pools](https://docs.databricks.com/clusters/instance-pools/index.html) to reduce cluster start and auto-scaling times by maintaining a set of idle, ready-to-use instances.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code in a databricks_cluster.


    :param bool beta: if we should limit the search only to runtimes that are in Beta stage. Default to `false`.
    :param bool genomics: if we should limit the search only to Genomics (HLS) runtimes. Default to `false`.
    :param bool gpu: if we should limit the search only to runtimes that support GPUs. Default to `false`.
    :param bool graviton: if we should limit the search only to runtimes supporting AWS Graviton CPUs. Default to `false`.
    :param bool latest: if we should return only the latest version if there is more than one result.  Default to `true`. If set to `false` and multiple versions are matching, throws an error.
    :param bool long_term_support: if we should limit the search only to LTS (long term support) & ESR (extended support) versions. Default to `false`.
    :param bool ml: if we should limit the search only to ML runtimes. Default to `false`.
    :param bool photon: if we should limit the search only to Photon runtimes. Default to `false`.
    :param str scala: if we should limit the search only to runtimes that are based on specific Scala version. Default to `2.12`.
    :param str spark_version: if we should limit the search only to runtimes that are based on specific Spark version. Default to empty string.  It could be specified as `3`, or `3.0`, or full version, like, `3.0.1`.
    """
    ...
